@@ -1,4 +1,4 @@
-/*      $Id: client.h,v 1.118 2004/08/24 05:58:06 olivier Exp $
+/*      $Id: client.h,v 1.121 2004/08/28 23:24:18 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -71,64 +71,76 @@
 #define UPDATE_FRAME                    (1<<1)
 #define UPDATE_GRAVITY                  (1<<2)
 #define UPDATE_CACHE                    (1<<3)
-#define UPDATE_ALL                      (UPDATE_KEYGRABS | UPDATE_FRAME | UPDATE_GRAVITY | UPDATE_CACHE)
+#define UPDATE_ALL                      (UPDATE_KEYGRABS | \
+                                         UPDATE_FRAME | \
+                                         UPDATE_GRAVITY | \
+                                         UPDATE_CACHE)
 
 #define CLIENT_MIN_VISIBLE              10      /* pixels */
 
-#define CLIENT_FLAG_HAS_BORDER         (1L<<0)
-#define CLIENT_FLAG_HAS_MENU           (1L<<1)
-#define CLIENT_FLAG_HAS_MAXIMIZE       (1L<<2)
-#define CLIENT_FLAG_HAS_CLOSE          (1L<<3)
-#define CLIENT_FLAG_HAS_HIDE           (1L<<4)
-#define CLIENT_FLAG_HAS_MOVE           (1L<<5)
-#define CLIENT_FLAG_HAS_RESIZE         (1L<<6)
-#define CLIENT_FLAG_HAS_STICK          (1L<<7)
-#define CLIENT_FLAG_HAS_STRUT          (1L<<8)
-#define CLIENT_FLAG_HAS_STRUT_PARTIAL  (1L<<9)
-#define CLIENT_FLAG_HAS_USER_TIME      (1L<<10)
-#define CLIENT_FLAG_FOCUS              (1L<<11)
-#define CLIENT_FLAG_ABOVE              (1L<<12)
-#define CLIENT_FLAG_BELOW              (1L<<13)
-#define CLIENT_FLAG_FULLSCREEN         (1L<<14)
-#define CLIENT_FLAG_IS_RESIZABLE       (1L<<15)
-#define CLIENT_FLAG_MAP_PENDING        (1L<<16)
-#define CLIENT_FLAG_VISIBLE            (1L<<17)
-#define CLIENT_FLAG_ICONIFIED          (1L<<18)
-#define CLIENT_FLAG_MANAGED            (1L<<19)
-#define CLIENT_FLAG_MAXIMIZED_VERT     (1L<<20)
-#define CLIENT_FLAG_MAXIMIZED_HORIZ    (1L<<21)
-#define CLIENT_FLAG_MAXIMIZED          (CLIENT_FLAG_MAXIMIZED_VERT | CLIENT_FLAG_MAXIMIZED_HORIZ)
-#define CLIENT_FLAG_SHADED             (1L<<22)
-#define CLIENT_FLAG_SKIP_PAGER         (1L<<23)
-#define CLIENT_FLAG_SKIP_TASKBAR       (1L<<24)
-#define CLIENT_FLAG_STATE_MODAL        (1L<<25)
-#define CLIENT_FLAG_STICKY             (1L<<26)
-#define CLIENT_FLAG_MOVING_RESIZING    (1L<<27)
-#define CLIENT_FLAG_NAME_CHANGED       (1L<<28)
-#define CLIENT_FLAG_SESSION_MANAGED    (1L<<29)
-#define CLIENT_FLAG_WORKSPACE_SET      (1L<<30)
-#define CLIENT_FLAG_WAS_SHOWN          (1L<<31)
+#define XFWM_FLAG_HAS_BORDER           (1L<<0)
+#define XFWM_FLAG_HAS_MENU             (1L<<1)
+#define XFWM_FLAG_HAS_MAXIMIZE         (1L<<2)
+#define XFWM_FLAG_HAS_CLOSE            (1L<<3)
+#define XFWM_FLAG_HAS_HIDE             (1L<<4)
+#define XFWM_FLAG_HAS_MOVE             (1L<<5)
+#define XFWM_FLAG_HAS_RESIZE           (1L<<6)
+#define XFWM_FLAG_HAS_STICK            (1L<<7)
+#define XFWM_FLAG_FOCUS                (1L<<8)
+#define XFWM_FLAG_IS_RESIZABLE         (1L<<9)
+#define XFWM_FLAG_MAP_PENDING          (1L<<10)
+#define XFWM_FLAG_VISIBLE              (1L<<11)
+#define XFWM_FLAG_MANAGED              (1L<<13)
+#define XFWM_FLAG_SESSION_MANAGED      (1L<<14)
+#define XFWM_FLAG_WORKSPACE_SET        (1L<<15)
+#define XFWM_FLAG_WAS_SHOWN            (1L<<16)
+#define XFWM_FLAG_DRAW_ACTIVE          (1L<<17)
+#define XFWM_FLAG_SEEN_ACTIVE          (1L<<18)
+#define XFWM_FLAG_FIRST_MAP            (1L<<19)
+#define XFWM_FLAG_LEGACY_FULLSCREEN    (1L<<20)
+#define XFWM_FLAG_MOVING_RESIZING      (1L<<21)
+
+#define CLIENT_FLAG_HAS_STRUT          (1L<<0)
+#define CLIENT_FLAG_HAS_STRUT_PARTIAL  (1L<<1)
+#define CLIENT_FLAG_HAS_USER_TIME      (1L<<2)
+#define CLIENT_FLAG_ABOVE              (1L<<3)
+#define CLIENT_FLAG_BELOW              (1L<<4)
+#define CLIENT_FLAG_FULLSCREEN         (1L<<5)
+#define CLIENT_FLAG_ICONIFIED          (1L<<6)
+#define CLIENT_FLAG_MAXIMIZED_VERT     (1L<<7)
+#define CLIENT_FLAG_MAXIMIZED_HORIZ    (1L<<8)
+#define CLIENT_FLAG_MAXIMIZED          (CLIENT_FLAG_MAXIMIZED_VERT | \
+                                        CLIENT_FLAG_MAXIMIZED_HORIZ)
+#define CLIENT_FLAG_SHADED             (1L<<9)
+#define CLIENT_FLAG_SKIP_PAGER         (1L<<10)
+#define CLIENT_FLAG_SKIP_TASKBAR       (1L<<11)
+#define CLIENT_FLAG_STATE_MODAL        (1L<<12)
+#define CLIENT_FLAG_STICKY             (1L<<13)
+#define CLIENT_FLAG_NAME_CHANGED       (1L<<15)
+#define CLIENT_FLAG_DEMANDS_ATTENTION  (1L<<16)
 
 #define WM_FLAG_DELETE                 (1L<<0)
 #define WM_FLAG_INPUT                  (1L<<1)
 #define WM_FLAG_TAKEFOCUS              (1L<<2)
 #define WM_FLAG_CONTEXT_HELP           (1L<<3)
+#define WM_FLAG_URGENT                 (1L<<4)
 
-#define CLIENT_FLAG_INITIAL_VALUES     CLIENT_FLAG_HAS_BORDER | \
-                                       CLIENT_FLAG_HAS_MENU | \
-                                       CLIENT_FLAG_HAS_MAXIMIZE | \
-                                       CLIENT_FLAG_HAS_STICK | \
-                                       CLIENT_FLAG_HAS_HIDE | \
-                                       CLIENT_FLAG_HAS_CLOSE | \
-                                       CLIENT_FLAG_HAS_MOVE | \
-                                       CLIENT_FLAG_HAS_RESIZE
+#define CLIENT_FLAG_INITIAL_VALUES     XFWM_FLAG_HAS_BORDER | \
+                                       XFWM_FLAG_HAS_MENU | \
+                                       XFWM_FLAG_HAS_MAXIMIZE | \
+                                       XFWM_FLAG_HAS_STICK | \
+                                       XFWM_FLAG_HAS_HIDE | \
+                                       XFWM_FLAG_HAS_CLOSE | \
+                                       XFWM_FLAG_HAS_MOVE | \
+                                       XFWM_FLAG_HAS_RESIZE | \
+                                       XFWM_FLAG_FIRST_MAP
 
 #define ALL_WORKSPACES                 (int) 0xFFFFFFFF
 
 #define CONSTRAINED_WINDOW(c)          ((c->win_layer > WIN_LAYER_DESKTOP) && \
                                         (c->win_layer < WIN_LAYER_ABOVE_DOCK) && \
                                        !(c->type & (WINDOW_DESKTOP | WINDOW_DOCK)) && \
-                                       !(c->legacy_fullscreen))
+                                       !FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN))
 
 #define WINDOW_TYPE_DIALOG               (WINDOW_DIALOG | WINDOW_MODAL_DIALOG)
 #define WINDOW_TYPE_DONT_PLACE           (WINDOW_DESKTOP | WINDOW_DOCK | WINDOW_SPLASHSCREEN)
@@ -142,9 +154,15 @@
 #define FLAG_UNSET(flag,bits)                  (flag &= ~(bits))
 #define FLAG_TOGGLE(flag,bits)                 (flag ^= (bits))
 
-#define CLIENT_CAN_HIDE_WINDOW(c)       (!(c->transient_for) && FLAG_TEST_AND_NOT(c->flags, CLIENT_FLAG_HAS_HIDE, CLIENT_FLAG_SKIP_TASKBAR))
-#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   FLAG_TEST_ALL(c->flags, CLIENT_FLAG_HAS_MAXIMIZE | CLIENT_FLAG_HAS_RESIZE | CLIENT_FLAG_IS_RESIZABLE)
-#define CLIENT_CAN_STICK_WINDOW(c)      (!(c->transient_for) && FLAG_TEST_AND_NOT(c->flags, CLIENT_FLAG_HAS_STICK, CLIENT_FLAG_SKIP_TASKBAR))
+#define CLIENT_CAN_HIDE_WINDOW(c)       (!(c->transient_for) && \
+                                         FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_HIDE) && \
+                                         !FLAG_TEST(c->flags, CLIENT_FLAG_SKIP_TASKBAR))
+#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   FLAG_TEST_ALL(c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE | \
+                                                                     XFWM_FLAG_HAS_RESIZE | \
+                                                                     XFWM_FLAG_IS_RESIZABLE)
+#define CLIENT_CAN_STICK_WINDOW(c)      (!(c->transient_for) && \
+                                         FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_STICK) && \
+                                         !FLAG_TEST(c->flags, CLIENT_FLAG_SKIP_TASKBAR))
 
 typedef enum
 {
@@ -196,9 +214,6 @@ struct _Client
     Client *next;
     Client *prev;
     netWindowType type;
-    gboolean draw_active;
-    gboolean first_map;
-    gboolean legacy_fullscreen;
     int x;
     int y;
     int width;
@@ -225,6 +240,9 @@ struct _Client
     Time user_time;
     unsigned long flags;
     unsigned long wm_flags;
+    unsigned long xfwm_flags;
+    /* Timout to manage blinking decorations for urgent windows */
+    guint blink_timeout_id;
     /* Pixmap caching */
     ClientPixmapCache pm_cache;
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
@@ -239,6 +257,7 @@ extern unsigned int client_count;
 Display *clientGetXDisplay (Client *);
 void clientClearLastOpTime (Client *);
 void clientUpdateWinState (Client *, XClientMessageEvent *);
+void clientUpdateUrgency (Client *);
 void clientCoordGravitate (Client *, int, int *, int *);
 void clientGravitate (Client *, int);
 void clientConfigure (Client *, XWindowChanges *, int, unsigned short);
